[][src]Struct c2rust_asm_casts::AsmCast

pub struct AsmCast<Out, In>(_);

Pseudo-structure that provides the inner type definition and cast functions for every pair of types used in C2Rust's implementation of tied inline assembly operands. For two tied operands of types In and Out, this implementation provides the smallest type that can hold both operands, along with the casts to convert each operand to this type.